@@ -49,7 +49,7 @@ class ExaConnection(object):
             , password=None
             , schema=''
             , autocommit=constant.DEFAULT_AUTOCOMMIT
-            , snapshot_transactions=False
+            , snapshot_transactions=None
             , connection_timeout=constant.DEFAULT_CONNECTION_TIMEOUT
             , socket_timeout=constant.DEFAULT_SOCKET_TIMEOUT
             , query_timeout=constant.DEFAULT_QUERY_TIMEOUT
@@ -71,8 +71,10 @@ class ExaConnection(object):
             , client_name=None
             , client_version=None
             , client_os_username=None
-            , protocol_version=constant.PROTOCOL_V1
+            , protocol_version=constant.PROTOCOL_V3
             , websocket_sslopt=None
+            , access_token=None
+            , refresh_token=None
             ):
         """
         Exasol connection object
@@ -82,7 +84,7 @@ class ExaConnection(object):
         :param password: Password
         :param schema: Open schema after connection (Default: '', no schema)
         :param autocommit: Enable autocommit on connection (Default: True)
-        :param snapshot_transactions: Enable snapshot transactions on connection (Default: False)
+        :param snapshot_transactions: Explicitly enable or disable snapshot transactions on connection (Default: None, database default)
         :param connection_timeout: Socket timeout in seconds used to establish connection (Default: 10)
         :param socket_timeout: Socket timeout in seconds used for requests after connection was established (Default: 30)
         :param query_timeout: Maximum execution time of queries before automatic abort, in seconds (Default: 0, no timeout)
@@ -104,8 +106,10 @@ class ExaConnection(object):
         :param client_name: Custom name of client application displayed in Exasol sessions tables (Default: PyEXASOL)
         :param client_version: Custom version of client application (Default: pyexasol.__version__)
         :param client_os_username: Custom OS username displayed in Exasol sessions table (Default: getpass.getuser())
-        :param protocol_version: Major WebSocket protocol version requested for connection (Default: pyexasol.PROTOCOL_V1)
+        :param protocol_version: Major WebSocket protocol version requested for connection (Default: pyexasol.PROTOCOL_V3)
         :param websocket_sslopt: Set custom SSL options for WebSocket client (Default: None)
+        :param access_token: OpenID access token to use for the login process
+        :param refresh_token: OpenID refresh token to use for the login process
         """
 
         self.options = {
@@ -145,7 +149,10 @@ class ExaConnection(object):
             'client_os_username': client_os_username,
 
             'protocol_version': protocol_version,
-            'websocket_sslopt': websocket_sslopt
+            'websocket_sslopt': websocket_sslopt,
+
+            'access_token': access_token,
+            'refresh_token': refresh_token,
         }
 
         self.login_info = {}
@@ -602,14 +609,13 @@ class ExaConnection(object):
     def _login(self):
         start_ts = time.time()
 
-        ret = self.req({
-            'command': 'login',
-            'protocolVersion': self.options['protocol_version'],
-        })
+        if self.options['access_token'] or self.options['refresh_token']:
+            auth_params = self._login_token()
+        else:
+            auth_params = self._login_password()
 
         self.login_info = self.req({
-            'username': self.options['user'],
-            'password': self._encrypt_password(ret['responseData']['publicKeyPem']),
+            **auth_params,
             'driverName': f'{constant.DRIVER_NAME} {__version__}',
             'clientName': self.options['client_name'] if self.options['client_name'] else constant.DRIVER_NAME,
             'clientVersion': self.options['client_version'] if self.options['client_version'] else __version__,
@@ -617,12 +623,7 @@ class ExaConnection(object):
             'clientOsUsername': self.options['client_os_username'] if self.options['client_os_username'] else getpass.getuser(),
             'clientRuntime': f'Python {platform.python_version()}',
             'useCompression': self.options['compression'],
-            'attributes': {
-                'currentSchema': str(self.options['schema']),
-                'autocommit': self.options['autocommit'],
-                'queryTimeout': self.options['query_timeout'],
-                'snapshotTransactionsEnabled': self.options['snapshot_transactions'],
-            }
+            'attributes': self._get_login_attributes()
         })['responseData']
 
         self.login_time = time.time() - start_ts
@@ -631,6 +632,35 @@ class ExaConnection(object):
             self._ws_send = lambda x: self._ws.send_binary(zlib.compress(x.encode(), 1))
             self._ws_recv = lambda: zlib.decompress(self._ws.recv())
 
+    def _login_password(self):
+        ret = self.req({
+            'command': 'login',
+            'protocolVersion': self.options['protocol_version'],
+        })
+
+        auth_params = {
+            'username': self.options['user'],
+            'password': self._encrypt_password(ret['responseData']['publicKeyPem']),
+        }
+
+        return auth_params
+
+    def _login_token(self):
+        self.req({
+            'command': 'loginToken',
+            'protocolVersion': self.options['protocol_version'],
+        })
+
+        auth_params = {}
+
+        if self.options['refresh_token']:
+            auth_params['refreshToken'] = self.options['refresh_token']
+
+        if self.options['access_token']:
+            auth_params['accessToken'] = self.options['access_token']
+
+        return auth_params
+
     def _encrypt_password(self, public_key_pem):
         pk = rsa.PublicKey.load_pkcs1(public_key_pem.encode())
         return base64.b64encode(rsa.encrypt(self.options['password'].encode(), pk)).decode()
@@ -699,6 +729,18 @@ class ExaConnection(object):
 
         return options
 
+    def _get_login_attributes(self):
+        attributes = {
+            'currentSchema': str(self.options['schema']),
+            'autocommit': self.options['autocommit'],
+            'queryTimeout': self.options['query_timeout'],
+        }
+
+        if self.options['snapshot_transactions'] is not None:
+            attributes['snapshotTransactionsEnabled'] = self.options['snapshot_transactions']
+
+        return attributes
+
     def _process_dsn(self, dsn):
         """
         Parse DSN, expand ranges and resolve IP addresses for all hosts
